@@ -33,9 +33,7 @@ class LspModel(BaseModel):
     """
 
     class Config:
-        alias_generator = partial(
-            re.sub, r"_([a-z])", lambda match: match.group(1).upper()
-        )
+        alias_generator = partial(re.sub, r"_([a-z])", lambda match: match.group(1).upper())
         allow_population_by_field_name = True
 
     def dict(self, *args: object, **kwargs: Any) -> Dict[str, object]:
